#ifndef NT2_INCLUDE_FUNCTIONS_NORMPDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NORMPDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/normpdf.hpp>

#endif
